summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorSpacebarRacecar <42380065+SpacebarRacecar@users.noreply.github.com>2018-10-22 22:23:22 +0200
committerDrashna Jaelre <drashna@live.com>2018-10-22 22:23:22 +0200
commit704a2e8d3c0bd15f6c8accd5a39fb88ca6c9e2d5 (patch)
treee3ed96d6cc1d4a78c65db1dc571956feeaef83e6
parente7451448361b0d1490f74aae6dfe4f80e86ea1ca (diff)
downloadqmk_firmware-704a2e8d3c0bd15f6c8accd5a39fb88ca6c9e2d5.tar.gz
qmk_firmware-704a2e8d3c0bd15f6c8accd5a39fb88ca6c9e2d5.tar.xz
Keymap: Updates to personal userspace and keymaps (#4206)
* - updated personal userspace - updated fc660c, niu mini and planck keymaps - added prime_o keymap * Rename README.md to readme.md
-rw-r--r--keyboards/fc660c/keymaps/spacebarracecar/README.md4
-rw-r--r--keyboards/fc660c/keymaps/spacebarracecar/config.h11
-rw-r--r--keyboards/fc660c/keymaps/spacebarracecar/keymap.c6
-rw-r--r--keyboards/fc660c/keymaps/spacebarracecar/readme.md5
-rw-r--r--keyboards/niu_mini/keymaps/spacebarracecar/config.h1
-rw-r--r--keyboards/niu_mini/keymaps/spacebarracecar/keymap.c17
-rw-r--r--keyboards/niu_mini/keymaps/spacebarracecar/readme.md6
-rw-r--r--keyboards/planck/keymaps/spacebarracecar/config.h2
-rw-r--r--keyboards/planck/keymaps/spacebarracecar/keymap.c19
-rw-r--r--keyboards/planck/keymaps/spacebarracecar/readme.md7
-rw-r--r--keyboards/primekb/prime_o/keymaps/spacebarracecar/config.h1
-rw-r--r--keyboards/primekb/prime_o/keymaps/spacebarracecar/keymap.c286
-rw-r--r--keyboards/primekb/prime_o/keymaps/spacebarracecar/readme.md6
-rw-r--r--keyboards/primekb/prime_o/keymaps/spacebarracecar/rules.mk22
-rw-r--r--users/spacebarracecar/spacebarracecar.c47
-rw-r--r--users/spacebarracecar/spacebarracecar.h25
16 files changed, 411 insertions, 54 deletions
diff --git a/keyboards/fc660c/keymaps/spacebarracecar/README.md b/keyboards/fc660c/keymaps/spacebarracecar/README.md
deleted file mode 100644
index 7d87ef8cf..000000000
--- a/keyboards/fc660c/keymaps/spacebarracecar/README.md
+++ /dev/null
@@ -1,4 +0,0 @@
-# US International keymap for PCs with German set as input language
-
-This keymap emulates a US International layout including a deadkey layer on PCs that have German set as the input language.
-This allows the use of the keyboard on any PC in Germany without the need of changing the input language.
diff --git a/keyboards/fc660c/keymaps/spacebarracecar/config.h b/keyboards/fc660c/keymaps/spacebarracecar/config.h
index 9c9b00656..9d83a2700 100644
--- a/keyboards/fc660c/keymaps/spacebarracecar/config.h
+++ b/keyboards/fc660c/keymaps/spacebarracecar/config.h
@@ -1,9 +1,8 @@
#pragma once
-// higher value means deeper actuation point, less sensitive
-// be careful and only make small adjustments (steps of 1 or 2).
-// too high and keys will fail to actuate. too low and keys will actuate spontaneously.
-// test all keys before further adjustment.
-// this should probably stay in the range +/-5.
+/*
+higher value means deeper actuation point, less sensitive
+this should probably stay in the range +/-5.
+*/
#undef ACTUATION_DEPTH_ADJUSTMENT
-#define ACTUATION_DEPTH_ADJUSTMENT +2
+#define ACTUATION_DEPTH_ADJUSTMENT -1
diff --git a/keyboards/fc660c/keymaps/spacebarracecar/keymap.c b/keyboards/fc660c/keymaps/spacebarracecar/keymap.c
index 2cbef10bb..760b83b9f 100644
--- a/keyboards/fc660c/keymaps/spacebarracecar/keymap.c
+++ b/keyboards/fc660c/keymaps/spacebarracecar/keymap.c
@@ -28,11 +28,11 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
_______,KC_PGDN,KC_UP, KC_PGUP,KC_HOME,XXXXXXX,XXXXXXX,XXXXXXX,GUIU, XXXXXXX,XXXXXXX,XXXXXXX,XXXXXXX,XXXXXXX, CU_ESCT,
_______,KC_LEFT,KC_DOWN,KC_RGHT,KC_END, XXXXXXX,XXXXXXX,GUIL, GUID, GUIR, XXXXXXX,XXXXXXX, KC_ENT,
_______,KC_MPRV,KC_MPLY,KC_MNXT,KC_VOLD,KC_VOLU,KC_MUTE,XXXXXXX,XXXXXXX,XXXXXXX,XXXXXXX,_______, KC_PGUP,
- RESET, _______,_______, _______, _______,_______,_______, KC_HOME,KC_PGDN,KC_END
+ RESET, _______,_______, KC_SPC, _______,_______,_______, KC_HOME,KC_PGDN,KC_END
)
};
-bool process_record_user(uint16_t keycode, keyrecord_t *record) {
- return process_record_userspace(keycode, record);
+bool process_record_keymap(uint16_t keycode, keyrecord_t *record) {
+ return true;
}
diff --git a/keyboards/fc660c/keymaps/spacebarracecar/readme.md b/keyboards/fc660c/keymaps/spacebarracecar/readme.md
new file mode 100644
index 000000000..88c447e75
--- /dev/null
+++ b/keyboards/fc660c/keymaps/spacebarracecar/readme.md
@@ -0,0 +1,5 @@
+# SpacebarRacecar US-International FC660C Keymap for German PCs
+
+This keymap emulates most keys of the US-International layout on PCs that have German set as input language.
+This allows the use of the keyboard on any PC in Germany without the need to change any settings.
+The keymap is mostly based on the US-International layout.
diff --git a/keyboards/niu_mini/keymaps/spacebarracecar/config.h b/keyboards/niu_mini/keymaps/spacebarracecar/config.h
index e69de29bb..6f70f09be 100644
--- a/keyboards/niu_mini/keymaps/spacebarracecar/config.h
+++ b/keyboards/niu_mini/keymaps/spacebarracecar/config.h
@@ -0,0 +1 @@
+#pragma once
diff --git a/keyboards/niu_mini/keymaps/spacebarracecar/keymap.c b/keyboards/niu_mini/keymaps/spacebarracecar/keymap.c
index b850e5fda..c3f6fb09a 100644
--- a/keyboards/niu_mini/keymaps/spacebarracecar/keymap.c
+++ b/keyboards/niu_mini/keymaps/spacebarracecar/keymap.c
@@ -12,7 +12,7 @@ enum layers {
const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
-/* Base Layer
+/* Base
,-----------------------------------------------------------------------------------------------------------------------.
|Tab |Q |W |E |R |T |Z |U |I |O |P |Backspace|
|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
@@ -68,7 +68,7 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
_______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______
),
-/* Dead-Key
+/* Deadkey
,-----------------------------------------------------------------------------------------------------------------------.
| | | | | | | |Ü | |Ö | | |
|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
@@ -87,15 +87,15 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
_______, _______, _______, _______, _______, CU_DDQ, CU_DDQ, _______, _______, _______, _______, _______
),
-/* Nav
+/* Navigation
,-----------------------------------------------------------------------------------------------------------------------.
-|Caps Lock|PageDown |Up |PageUp |Home | | | |Win+Up | | |Del |
+|ESCT |PageDown |Up |PageUp |Home | | | |Win+Up | | |Del |
|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
| |Left |Down |Right |End | | |Win+Left |Win+Down |Win+Right| |Enter |
|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
| |Prev |Pause |Next |LowerVol |RaiseVol |Mute | | | | | |
|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
-| | | | | | | | | | |RESET | |
+|RESET | | | | | | | | | | |Game |
`-----------------------------------------------------------------------------------------------------------------------'
*/
@@ -103,12 +103,12 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
CU_ESCT, KC_PGDN, KC_UP, KC_PGUP, KC_HOME, XXXXXXX, XXXXXXX, XXXXXXX, GUIU, XXXXXXX, XXXXXXX, KC_DEL,
_______, KC_LEFT, KC_DOWN, KC_RGHT, KC_END, XXXXXXX, XXXXXXX, GUIL, GUID, GUIR, RGB_M_P, KC_ENT,
_______, KC_MPRV, KC_MPLY, KC_MNXT, KC_VOLD, KC_VOLU, KC_MUTE, RGB_TOG, RGB_MOD, RGB_HUI, CU_RGBV, _______,
- RESET, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, CU_GAME
+ RESET, _______, _______, _______, _______, KC_SPC, KC_ENT, _______, _______, _______, _______, CU_GAME
)
};
-bool process_record_user(uint16_t keycode, keyrecord_t *record) {
+bool process_record_keymap(uint16_t keycode, keyrecord_t *record) {
switch (keycode) {
case MO(_LOWER):
if (game){
@@ -121,6 +121,7 @@ switch (keycode) {
} else {
return true;
}
+ default:
+ return true;
}
- return process_record_userspace(keycode, record);
}
diff --git a/keyboards/niu_mini/keymaps/spacebarracecar/readme.md b/keyboards/niu_mini/keymaps/spacebarracecar/readme.md
index 88d722186..967274381 100644
--- a/keyboards/niu_mini/keymaps/spacebarracecar/readme.md
+++ b/keyboards/niu_mini/keymaps/spacebarracecar/readme.md
@@ -1,3 +1,5 @@
-# US-International like Niu Mini layout for PCs with German set as input language
+# SpacebarRacecar US-International NIU Mini Keymap for German PCs
-This layout aims to provide a US-International like layout for PCs that have German set as Input Language. This is useful for users living in germany, because it enables the use of the Niu Mini on any pc without having to switch the input language. It's mostly based on the Planck default layout, but adds essential features for german input, like a dead key layer to access ä, ö, ü.
+This keymap emulates most keys of the US-International layout on PCs that have German set as input language.
+This allows the use of the keyboard on any PC in Germany without the need to change any settings.
+The keymap is mostly based on the Planck default layout but adds essential features for german input, like access to Ä, Ö, Ü, ß.
diff --git a/keyboards/planck/keymaps/spacebarracecar/config.h b/keyboards/planck/keymaps/spacebarracecar/config.h
index 9b55fa93a..4f48857fe 100644
--- a/keyboards/planck/keymaps/spacebarracecar/config.h
+++ b/keyboards/planck/keymaps/spacebarracecar/config.h
@@ -1,3 +1,5 @@
+#pragma once
+
#ifdef AUDIO_ENABLE
#define STARTUP_SONG SONG(NO_SOUND)
#endif
diff --git a/keyboards/planck/keymaps/spacebarracecar/keymap.c b/keyboards/planck/keymaps/spacebarracecar/keymap.c
index 705f78f8e..db91231bf 100644
--- a/keyboards/planck/keymaps/spacebarracecar/keymap.c
+++ b/keyboards/planck/keymaps/spacebarracecar/keymap.c
@@ -13,7 +13,7 @@ enum layers {
const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
-/* Base Layer
+/* Base
,-----------------------------------------------------------------------------------------------------------------------.
|Tab |Q |W |E |R |T |Z |U |I |O |P |Backspace|
|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
@@ -76,7 +76,7 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
KC_LCTL, KC_LALT, KC_LGUI, KC_DOWN, KC_UP, XXXXXXX, XXXXXXX, XXXXXXX, XXXXXXX, XXXXXXX, MU_MOD, MU_OFF
),
-/* Dead-Key
+/* Deadkey
,-----------------------------------------------------------------------------------------------------------------------.
| | | | | | | |Ü | |Ö | | |
|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
@@ -92,18 +92,18 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
KC_TAB, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_UE, CU_ED, CU_OE, CU_ED, KC_BSPC,
CU_NAV, CU_AE, CU_SS, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_DDQ,
CU_LSFT, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_RSFT,
- KC_LCTL, XXXXXXX, KC_LGUI, KC_LALT, LOWER, KC_SPC, KC_ENT, RAISE, KC_RALT, KC_RGUI, KC_APP, KC_RCTL
+ KC_LCTL, XXXXXXX, KC_LGUI, KC_LALT, LOWER, CU_DDQ, CU_DDQ, RAISE, KC_RALT, KC_RGUI, KC_APP, KC_RCTL
),
-/* Nav
+/* Navigation
,-----------------------------------------------------------------------------------------------------------------------.
-|Caps Lock|PageDown |Up |PageUp |Home | | | |Win+Up | | |Del |
+|ESCT |PageDown |Up |PageUp |Home | | | |Win+Up | | |Del |
|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
| |Left |Down |Right |End | | |Win+Left |Win+Down |Win+Right| |Enter |
|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
| |Prev |Pause |Next |LowerVol |RaiseVol |Mute | | | | | |
|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
-| | | | | | | | | | |RESET | |
+|RESET | | | | | | | | | | |Game |
`-----------------------------------------------------------------------------------------------------------------------'
*/
@@ -111,12 +111,12 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
CU_ESCT, KC_PGDN, KC_UP, KC_PGUP, KC_HOME, XXXXXXX, XXXXXXX, XXXXXXX, GUIU, XXXXXXX, XXXXXXX, KC_DEL,
_______, KC_LEFT, KC_DOWN, KC_RGHT, KC_END, XXXXXXX, XXXXXXX, GUIL, GUID, GUIR, XXXXXXX, KC_ENT,
_______, KC_MPRV, KC_MPLY, KC_MNXT, KC_VOLD, KC_VOLU, KC_MUTE, MU_ON, XXXXXXX, XXXXXXX, XXXXXXX, _______,
- RESET, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, CU_GAME
+ RESET, _______, _______, _______, _______, KC_SPC, KC_ENT, _______, _______, _______, _______, CU_GAME
)
};
-bool process_record_user(uint16_t keycode, keyrecord_t *record) {
+bool process_record_keymap(uint16_t keycode, keyrecord_t *record) {
switch (keycode) {
case MO(_LOWER):
if (game){
@@ -143,6 +143,7 @@ switch (keycode) {
layer_off(_MUSICMODE);
}
return true;
+ default:
+ return true;
}
- return process_record_userspace(keycode, record);
}
diff --git a/keyboards/planck/keymaps/spacebarracecar/readme.md b/keyboards/planck/keymaps/spacebarracecar/readme.md
index daa9c4ad2..c8e8134ca 100644
--- a/keyboards/planck/keymaps/spacebarracecar/readme.md
+++ b/keyboards/planck/keymaps/spacebarracecar/readme.md
@@ -1,4 +1,5 @@
-# US-International like Planck layout for PCs with German set as input language
-
-This layout aims to provide a US-International like layout for PCs that have German set as Input Language. This is useful for users living in germany, because it enables the use of the planck on any pc without having to switch the input language. It's mostly based on the Planck default layout, but adds essential features for german input, like a dead key layer to access ä, ö, ü.
+# SpacebarRacecar US-International Planck Keymap for German PCs
+This keymap emulates most keys of the US-International layout on PCs that have German set as input language.
+This allows the use of the keyboard on any PC in Germany without the need to change any settings.
+The keymap is mostly based on the Planck default layout but adds essential features for german input, like access to Ä, Ö, Ü, ß.
diff --git a/keyboards/primekb/prime_o/keymaps/spacebarracecar/config.h b/keyboards/primekb/prime_o/keymaps/spacebarracecar/config.h
new file mode 100644
index 000000000..6f70f09be
--- /dev/null
+++ b/keyboards/primekb/prime_o/keymaps/spacebarracecar/config.h
@@ -0,0 +1 @@
+#pragma once
diff --git a/keyboards/primekb/prime_o/keymaps/spacebarracecar/keymap.c b/keyboards/primekb/prime_o/keymaps/spacebarracecar/keymap.c
new file mode 100644
index 000000000..d38ff0d1d
--- /dev/null
+++ b/keyboards/primekb/prime_o/keymaps/spacebarracecar/keymap.c
@@ -0,0 +1,286 @@
+#include QMK_KEYBOARD_H
+#include "spacebarracecar.h"
+
+#define LOWER MO(_LOWER)
+#define RAISE MO(_RAISE)
+
+#define LEFTNUM
+
+enum layers {
+ _BASE,
+ _LOWER,
+ _RAISE,
+ _GAME = _NAV+1
+};
+
+const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
+
+#ifndef LEFTNUM
+/* Base
+,---------------------------------------------------------------------------------------------------------------------------------------------------------------.
+|` |1 |2 |3 |4 |5 |6 |7 |8 |9 |0 |\ |Numlock |/ |* |= |
+|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+|Tab |Q |W |E |R |T |Z |U |I |O |P |Backspace|7 |8 |9 |- |
+|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+|Esc/Nav |A |S |D |F |G |H |J |K |L |; |' |4 |5 |6 |+ |
+|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+|(/LShift |Y |X |C |V |B |N |M |, |. |/ |)/RShift |1 |2 |3 |Enter |
+|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+|RCtrl | |Alt |Win |Lower |Space |Enter |Raise |Win |AltGr | |LCtrl |00 |0 |. |Tab |
+`---------------------------------------------------------------------------------------------------------------------------------------------------------------'
+*/
+
+[_BASE] = LAYOUT(
+ CU_GRV, DE_1, DE_2, CU_3, DE_4, DE_5, CU_6, CU_7, CU_8, CU_9, CU_0, CU_BSLS, KC_NLCK, KC_PSLS, KC_PAST, KC_PMNS,
+ KC_TAB, DE_Q, DE_W, DE_E, DE_R, DE_T, CU_Z, DE_U, DE_I, DE_O, DE_P, KC_BSPC, KC_P7, KC_P8, KC_P9, KC_PPLS,
+ CU_NAV, DE_A, DE_S, DE_D, DE_F, DE_G, DE_H, DE_J, DE_K, DE_L, CU_SCLN, CU_QUOT, KC_P4, KC_P5, KC_P6, KC_PEQL,
+ CU_LSFT, CU_Y, DE_X, DE_C, DE_V, DE_B, DE_N, DE_M, CU_COMM, CU_DOT, CU_SLSH, CU_RSFT, KC_P1, KC_P2, KC_P3, KC_PENT,
+ KC_LCTL, XXXXXXX, KC_LGUI, KC_LALT, LOWER, KC_SPC, KC_ENT, RAISE, KC_RALT, KC_RGUI, KC_APP, KC_RCTL, KC_P00, KC_P0, KC_PDOT, KC_TAB
+),
+
+/* Lower
+,---------------------------------------------------------------------------------------------------------------------------------------------------------------.
+|` |1 |2 |3 |4 |5 |6 |7 |8 |9 |0 | |Numlock |/ |* |- |
+|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+|~ |! |" |# |$ |% |^ |& |* |( |) | |7 |8 |9 |+ |
+|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+| |@ |Strg+X |Strg+C |Strg+V | | |_ |+ |{ |} || |4 |5 |6 |= |
+|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+| |? | | | | | | | | | | |1 |2 |3 |Enter |
+|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+| | | | | | | | | | | | |00 |0 |. |Tab |
+`---------------------------------------------------------------------------------------------------------------------------------------------------------------'
+*/
+
+[_LOWER] = LAYOUT(
+ _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______,
+ DE_TILD, DE_EXLM, DE_DQOT, DE_HASH, DE_DLR, DE_PERC, CU_CIRC, DE_AMPR, DE_ASTR, DE_LPRN, DE_RPRN, _______, _______, _______, _______, _______,
+ _______, DE_AT, CTRLX, CTRLC, CTRLV, XXXXXXX, XXXXXXX, DE_UNDS, DE_PLUS, DE_LCBR, DE_RCBR, DE_PIPE, _______, _______, _______, _______,
+ _______, DE_EURO, XXXXXXX, XXXXXXX, XXXXXXX, XXXXXXX, XXXXXXX, XXXXXXX, _______, _______, _______, _______, _______, _______, _______, _______,
+ _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______
+),
+
+/* Raise
+,---------------------------------------------------------------------------------------------------------------------------------------------------------------.
+|` |1 |2 |3 |4 |5 |6 |7 |8 |9 |0 | |Numlock |/ |* |- |
+|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+|` |1 |2 |3 |4 |5 |6 |7 |8 |9 |0 | |7 |8 |9 |+ |
+|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+| |F1 |F2 |F3 |F4 |F5 |F6 |- |= |[ |] |\ |4 |5 |6 |= |
+|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+| |F7 |F8 |F9 |F10 |F11 |F12 | | | | | |1 |2 |3 |Enter |
+|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+| | | | | | | | | | | | |00 |0 |. |Tab |
+`---------------------------------------------------------------------------------------------------------------------------------------------------------------'
+*/
+
+[_RAISE] = LAYOUT(
+ _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______,
+ CU_GRV, DE_1, DE_2, CU_3, DE_4, DE_5, CU_6, CU_7, CU_8, CU_9, CU_0, _______, _______, _______, _______, _______,
+ _______, KC_F1, KC_F2, KC_F3, KC_F4, KC_F5, KC_F6, DE_MINS, CU_EQL, CU_LBRC, CU_RBRC, CU_BSLS, _______, _______, _______, _______,
+ _______, KC_F7, KC_F8, KC_F9, KC_F10, KC_F11, KC_F12, _______, _______, _______, _______, _______, _______, _______, _______, _______,
+ _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______
+),
+
+/* Deadkey
+,---------------------------------------------------------------------------------------------------------------------------------------------------------------.
+| | | | | | | | | | | | |Numlock |/ |* |- |
+|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+| | | | | | | |Ü | |Ö | | |7 |8 |9 |+ |
+|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+| |Ä |ß | | | | | | | | | |4 |5 |6 |= |
+|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+| | | | | | | | | | | | |1 |2 |3 |Enter |
+|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+| | | | | |" |" | | | | | |00 |0 |. |Tab |
+`---------------------------------------------------------------------------------------------------------------------------------------------------------------'
+*/
+
+[_DEADKEY] = LAYOUT(
+ CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, _______, _______, _______, _______,
+ KC_TAB, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_UE, CU_ED, CU_OE, CU_ED, _______, _______, _______, _______, _______,
+ _______, CU_AE, CU_SS, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_DDQ, _______, _______, _______, _______,
+ _______, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, _______, _______, _______, _______, _______,
+ _______, _______, _______, _______, _______, CU_DDQ, CU_DDQ, _______, _______, _______, _______, _______, _______, _______, _______, _______
+),
+
+/* Navigation
+,---------------------------------------------------------------------------------------------------------------------------------------------------------------.
+|Escape | | | | | | | | | | | |Numlock |/ |* |- |
+|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+|ESCT |PageDown |Up |PageUp |Home | | | |Win+Up | | |Del |7 |8 |9 |+ |
+|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+| |Left |Down |Right |End | | |Win+Left |Win+Down |Win+Right| |Enter |4 |5 |6 |= |
+|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+| |Prev |Pause |Next |LowerVol |RaiseVol |Mute | | | | | |1 |2 |3 |Enter |
+|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+|RESET | | | | | | | | | | |Game |00 |0 |. |Tab |
+`---------------------------------------------------------------------------------------------------------------------------------------------------------------'
+*/
+
+[_NAV] = LAYOUT(
+ KC_ESC, XXXXXXX, XXXXXXX, XXXXXXX, XXXXXXX, XXXXXXX, XXXXXXX, XXXXXXX, XXXXXXX, XXXXXXX, XXXXXXX, XXXXXXX, _______, _______, _______, _______,
+ CU_ESCT, KC_PGDN, KC_UP, KC_PGUP, KC_HOME, XXXXXXX, XXXXXXX, XXXXXXX, GUIU, XXXXXXX, XXXXXXX, KC_DEL, _______, _______, _______, _______,
+ _______, KC_LEFT, KC_DOWN, KC_RGHT, KC_END, XXXXXXX, XXXXXXX, GUIL, GUID, GUIR, XXXXXXX, KC_ENT, _______, _______, _______, _______,
+ _______, KC_MPRV, KC_MPLY, KC_MNXT, KC_VOLD, KC_VOLU, KC_MUTE, XXXXXXX, XXXXXXX, XXXXXXX, XXXXXXX, _______, _______, _______, _______, _______,
+ RESET, _______, _______, _______, _______, KC_SPC, KC_ENT, _______, _______, _______, _______, CU_GAME, _______, _______, _______, _______
+),
+
+// Can be used to place macros on the numpad
+[_GAME] = LAYOUT(
+ _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______,
+ _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______,
+ _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______,
+ _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______,
+ _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______
+)
+#endif
+
+#ifdef LEFTNUM
+/* Base
+,---------------------------------------------------------------------------------------------------------------------------------------------------------------.
+|- |* |/ |Numlock |` |1 |2 |3 |4 |5 |6 |7 |8 |9 |0 |\ |
+|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+|+ |7 |8 |9 |Tab |Q |W |E |R |T |Z |U |I |O |P |Backspace|
+|---------+---------+---------+---------|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+|= |4 |5 |6 |Esc/Nav |A |S |D |F |G |H |J |K |L |; |' |
+|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+|Enter |1 |2 |3 |(/LShift |Y |X |C |V |B |N |M |, |. |/ |)/RShift |
+|---------+---------+---------+---------|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+|Backspace|. |0 |00 |RCtrl | |Alt |Win |Lower |Space |Enter |Raise |Win |AltGr | |LCtrl |
+`---------------------------------------------------------------------------------------------------------------------------------------------------------------'
+*/
+
+[_BASE] = LAYOUT(
+ KC_PMNS, KC_PAST, KC_PSLS, KC_NLCK, CU_GRV, DE_1, DE_2, CU_3, DE_4, DE_5, CU_6, CU_7, CU_8, CU_9, CU_0, CU_BSLS,
+ KC_PPLS, KC_P7, KC_P8, KC_P9, KC_TAB, DE_Q, DE_W, DE_E, DE_R, DE_T, CU_Z, DE_U, DE_I, DE_O, DE_P, KC_BSPC,
+ KC_PEQL, KC_P4, KC_P5, KC_P6, CU_NAV, DE_A, DE_S, DE_D, DE_F, DE_G, DE_H, DE_J, DE_K, DE_L, CU_SCLN, CU_QUOT,
+ KC_PENT, KC_P1, KC_P2, KC_P3, CU_LSFT, CU_Y, DE_X, DE_C, DE_V, DE_B, DE_N, DE_M, CU_COMM, CU_DOT, CU_SLSH, CU_RSFT,
+ KC_BSPC, KC_PDOT, KC_P0, KC_P00, KC_LCTL, XXXXXXX, KC_LGUI, KC_LALT, LOWER, KC_SPC, KC_ENT, RAISE, KC_RALT, KC_RGUI, KC_APP, KC_RCTL
+),
+
+/* Lower
+,---------------------------------------------------------------------------------------------------------------------------------------------------------------.
+|- |* |/ |Numlock |` |1 |2 |3 |4 |5 |6 |7 |8 |9 |0 | |
+|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+|+ |7 |8 |9 |~ |! |" |# |$ |% |^ |& |* |( |) | |
+|---------+---------+---------+---------|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+|= |4 |5 |6 | |@ |Strg+X |Strg+C |Strg+V | | |_ |+ |{ |} || |
+|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+|Enter |1 |2 |3 | |? | | | | | | | | | | |
+|---------+---------+---------+---------|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+|Backspace|. |0 |00 | | | | | | | | | | | | |
+`---------------------------------------------------------------------------------------------------------------------------------------------------------------'
+*/
+
+[_LOWER] = LAYOUT(
+ _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______,
+ _______, _______, _______, _______, DE_TILD, DE_EXLM, DE_DQOT, DE_HASH, DE_DLR, DE_PERC, CU_CIRC, DE_AMPR, DE_ASTR, DE_LPRN, DE_RPRN, _______,
+ _______, _______, _______, _______, _______, DE_AT, CTRLX, CTRLC, CTRLV, XXXXXXX, XXXXXXX, DE_UNDS, DE_PLUS, DE_LCBR, DE_RCBR, DE_PIPE,
+ _______, _______, _______, _______, _______, DE_EURO, XXXXXXX, XXXXXXX, XXXXXXX, XXXXXXX, XXXXXXX, XXXXXXX, _______, _______, _______, _______,
+ _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______
+),
+
+/* Raise
+,---------------------------------------------------------------------------------------------------------------------------------------------------------------.
+|- |* |/ |Numlock |` |1 |2 |3 |4 |5 |6 |7 |8 |9 |0 | |
+|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+|+ |7 |8 |9 |` |1 |2 |3 |4 |5 |6 |7 |8 |9 |0 | |
+|---------+---------+---------+---------|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+|= |4 |5 |6 | |F1 |F2 |F3 |F4 |F5 |F6 |- |= |[ |] |\ |
+|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+|Enter |1 |2 |3 | |F7 |F8 |F9 |F10 |F11 |F12 | | | | | |
+|---------+---------+---------+---------|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+|Backspace|. |0 |00 | | | | | | | | | | | | |
+`---------------------------------------------------------------------------------------------------------------------------------------------------------------'
+*/
+
+[_RAISE] = LAYOUT(
+ _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______,
+ _______, _______, _______, _______, CU_GRV, DE_1, DE_2, CU_3, DE_4, DE_5, CU_6, CU_7, CU_8, CU_9, CU_0, _______,
+ _______, _______, _______, _______, _______, KC_F1, KC_F2, KC_F3, KC_F4, KC_F5, KC_F6, DE_MINS, CU_EQL, CU_LBRC, CU_RBRC, CU_BSLS,
+ _______, _______, _______, _______, _______, KC_F7, KC_F8, KC_F9, KC_F10, KC_F11, KC_F12, _______, _______, _______, _______, _______,
+ _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______
+),
+
+/* Deadkey
+,---------------------------------------------------------------------------------------------------------------------------------------------------------------.
+|- |* |/ |Numlock | | | | | | | | | | | | |
+|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+|+ |7 |8 |9 | | | | | | | |Ü | |Ö | | |
+|---------+---------+---------+---------|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+|= |4 |5 |6 | |Ä |ß | | | | | | | | | |
+|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+|Enter |1 |2 |3 | | | | | | | | | | | | |
+|---------+---------+---------+---------|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+|Backspace|. |0 |00 | | | | | |" |" | | | | | |
+`---------------------------------------------------------------------------------------------------------------------------------------------------------------'
+*/
+
+[_DEADKEY] = LAYOUT(
+ _______, _______, _______, _______, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED,
+ _______, _______, _______, _______, KC_TAB, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_UE, CU_ED, CU_OE, CU_ED, _______,
+ _______, _______, _______, _______, _______, CU_AE, CU_SS, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_DDQ,
+ _______, _______, _______, _______, _______, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, CU_ED, _______,
+ _______, _______, _______, _______, _______, _______, _______, _______, _______, CU_DDQ, CU_DDQ, _______, _______, _______, _______, _______
+),
+
+/* Navigation
+,---------------------------------------------------------------------------------------------------------------------------------------------------------------.
+|- |* |/ |Numlock |Escape | | | | | | | | | | | |
+|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+|+ |7 |8 |9 |ESCT |PageDown |Up |PageUp |Home | | | |Win+Up | | |Del |
+|---------+---------+---------+---------|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+|= |4 |5 |6 | |Left |Down |Right |End | | |Win+Left |Win+Down |Win+Right| |Enter |
+|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+|Enter |1 |2 |3 | |Prev |Pause |Next |LowerVol |RaiseVol |Mute | | | | | |
+|---------+---------+---------+---------|---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------+---------|
+|Backspace|. |0 |00 |RESET | | | | | | | | | | |Game |
+`---------------------------------------------------------------------------------------------------------------------------------------------------------------'
+*/
+
+[_NAV] = LAYOUT(
+ _______, _______, _______, _______, KC_ESC, XXXXXXX, XXXXXXX, XXXXXXX, XXXXXXX, XXXXXXX, XXXXXXX, XXXXXXX, XXXXXXX, XXXXXXX, XXXXXXX, XXXXXXX,
+ _______, _______, _______, _______, CU_ESCT, KC_PGDN, KC_UP, KC_PGUP, KC_HOME, XXXXXXX, XXXXXXX, XXXXXXX, GUIU, XXXXXXX, XXXXXXX, KC_DEL,
+ _______, _______, _______, _______, _______, KC_LEFT, KC_DOWN, KC_RGHT, KC_END, XXXXXXX, XXXXXXX, GUIL, GUID, GUIR, XXXXXXX, KC_ENT,
+ _______, _______, _______, _______, _______, KC_MPRV, KC_MPLY, KC_MNXT, KC_VOLD, KC_VOLU, KC_MUTE, XXXXXXX, XXXXXXX, XXXXXXX, XXXXXXX, _______,
+ _______, _______, _______, _______, RESET, _______, _______, _______, _______, KC_SPC, KC_ENT, _______, _______, _______, _______, CU_GAME
+),
+
+// Can be used to place macros on the numpad
+[_GAME] = LAYOUT(
+ _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______,
+ _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______,
+ _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______,
+ _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______,
+ _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______
+)
+#endif
+
+};
+
+bool process_record_keymap(uint16_t keycode, keyrecord_t *record) {
+switch (keycode) {
+ case MO(_LOWER):
+ if (game){
+ if(record->event.pressed) {
+ register_code(KC_SPC);
+ } else {
+ unregister_code(KC_SPC);
+ }
+ return false;
+ } else {
+ return true;
+ }
+ case CU_GAME:
+ if(record->event.pressed) {
+ if (game)
+ layer_on(_GAME);
+ else
+ layer_off(_GAME);
+ }
+ return false;
+ default:
+ return true;
+ }
+}
diff --git a/keyboards/primekb/prime_o/keymaps/spacebarracecar/readme.md b/keyboards/primekb/prime_o/keymaps/spacebarracecar/readme.md
new file mode 100644
index 000000000..eb8da3fa7
--- /dev/null
+++ b/keyboards/primekb/prime_o/keymaps/spacebarracecar/readme.md
@@ -0,0 +1,6 @@
+# SpacebarRacecar US-International Prime_O Keymap for German PCs
+
+This keymap emulates most keys of the US-International layout on PCs that have German set as input language.
+This allows the use of the keyboard on any PC in Germany without the need to change any settings.
+The keymap is mostly based on the Planck default layout but adds essential features for german input, like access to Ä, Ö, Ü, ß.
+Righthand Numpad is enabled by default, enable lefthand Numpad with #define LEFTNUM.
diff --git a/keyboards/primekb/prime_o/keymaps/spacebarracecar/rules.mk b/keyboards/primekb/prime_o/keymaps/spacebarracecar/rules.mk
new file mode 100644
index 000000000..f50334d5e
--- /dev/null
+++ b/keyboards/primekb/prime_o/keymaps/spacebarracecar/rules.mk
@@ -0,0 +1,22 @@
+# Build Options
+# change to "no" to disable the options, or define them in the Makefile in
+# the appropriate keymap folder that will get included automatically
+#
+BOOTMAGIC_ENABLE = no # Virtual DIP switch configuration(+1000)
+MOUSEKEY_ENABLE = no # Mouse keys(+4700)
+EXTRAKEY_ENABLE = yes # Audio control and System control(+450)
+CONSOLE_ENABLE = no # Console for debug(+400)
+COMMAND_ENABLE = no # Commands for debug and configuration
+NKRO_ENABLE = no # Nkey Rollover - if this doesn't work, see here: https://github.com/tmk/tmk_keyboard/wiki/FAQ#nkro-doesnt-work
+BACKLIGHT_ENABLE = no # Enable keyboard backlight functionality
+MIDI_ENABLE = no # MIDI controls
+AUDIO_ENABLE = no # Audio output on port C6
+UNICODE_ENABLE = no # Unicode
+BLUETOOTH_ENABLE = no # Enable Bluetooth with the Adafruit EZ-Key HID
+RGBLIGHT_ENABLE = no # Enable WS2812 RGB underlight. Do not enable this with audio at the same time.
+
+# Do not enable SLEEP_LED_ENABLE. it uses the same timer as BACKLIGHT_ENABLE
+SLEEP_LED_ENABLE = no # Breathing sleep LED during USB suspend
+
+# Userspace defines
+GERMAN_ENABLE = yes # Enable Custom US Ansi Keycodes for PC with German set as input language
diff --git a/users/spacebarracecar/spacebarracecar.c b/users/spacebarracecar/spacebarracecar.c
index 404331f8d..f7048869e 100644
--- a/users/spacebarracecar/spacebarracecar.c
+++ b/users/spacebarracecar/spacebarracecar.c
@@ -1,18 +1,29 @@
#include "spacebarracecar.h"
#ifdef GERMAN_ENABLE
+// These indicate if left and right shift are physically pressed
bool lshift = false;
bool rshift = false;
+
+// Interrupt and times for space cadet shift
bool lshiftp = false;
bool rshiftp = false;
uint16_t lshift_timer = 0;
uint16_t rshift_timer = 0;
+// Number of items that are saved in prev_kcs
uint8_t prev_indx = 0;
+// Used to save the last 6 actual keycodes activated by frankenkeycodes
uint16_t prev_kcs[6] = {0, 0, 0, 0, 0, 0};
+// If true the deadkey characters grave and circonflexe are not automatically escaped
bool esct = false;
+/*
+Used to add a keycode to a prev_kcs to remember it.
+When full the last code gets discarded and replaced by
+the new one.
+*/
void add_to_prev(uint16_t kc){
for (int i=0; i<prev_indx; i++){
if (kc == prev_kcs[i])
@@ -29,6 +40,13 @@ void add_to_prev(uint16_t kc){
}
}
+/*
+Unregisters all codes saved in prev_kcs and resets prev_indx.
+gets called on multiple occasions mainly when shift is released
+and when frankenkeycodes are pressed. Prevents output of
+wrong characters when really specific key combinations
+that would never occur during normal usage are pressed.
+*/
void unreg_prev(void){
if (prev_indx == 0)
return;
@@ -39,11 +57,14 @@ void unreg_prev(void){
}
#endif
-// stuff for nav esc
+// Interrupt and times for Nav/Esc
bool navesc = false;
uint16_t navesc_timer = 0;
+
+// If true Gui keys and Space Cadet Shift get disabled
bool game = false;
+// Interrupts all timers
void timer_timeout(void){
#ifdef GERMAN_ENABLE
lshiftp = false;
@@ -52,15 +73,19 @@ void timer_timeout(void){
navesc = false;
}
-bool process_record_userspace(uint16_t keycode, keyrecord_t *record) {
+bool process_record_user(uint16_t keycode, keyrecord_t *record) {
switch (keycode) {
case CU_GAME:
if(record->event.pressed) {
+ timer_timeout();
game = !game;
}
- return false;
+ // allows keymap to execute further commands when CU_GAME is pressed, for example enabling a macro layer
+ return process_record_keymap(keycode, record) && false;
case KC_LGUI:
case KC_RGUI:
+ if (record->event.pressed)
+ timer_timeout();
if (game)
return false;
else
@@ -77,11 +102,21 @@ bool process_record_userspace(uint16_t keycode, keyrecord_t *record) {
}
layer_off(_NAV);
}
- return false;
+ return false;
+ case KC_P00:
+ if(record->event.pressed) {
+ timer_timeout();
+ register_code(KC_P0);
+ unregister_code(KC_P0);
+ register_code(KC_P0);
+ unregister_code(KC_P0);
+ }
+ return false;
#ifdef RGBLIGHT_ENABLE
case CU_RGBV:
if(record->event.pressed) {
+ timer_timeout();
if (rgblight_get_val()+32>255)
rgblight_sethsv(rgblight_get_hue(), rgblight_get_sat(), 31);
else
@@ -133,6 +168,7 @@ bool process_record_userspace(uint16_t keycode, keyrecord_t *record) {
return false;
case CU_ESCT:
if(record->event.pressed) {
+ timer_timeout();
esct = !esct;
}
return false;
@@ -282,6 +318,7 @@ bool process_record_userspace(uint16_t keycode, keyrecord_t *record) {
case KC_LCTL:
case KC_RCTL:
if(!record->event.pressed) {
+ timer_timeout();
unregister_code(KC_Z);
unregister_code(KC_Y);
}
@@ -300,6 +337,6 @@ bool process_record_userspace(uint16_t keycode, keyrecord_t *record) {
#endif
}
- return true;
+ return process_record_keymap(keycode, record);
}
}
diff --git a/users/spacebarracecar/spacebarracecar.h b/users/spacebarracecar/spacebarracecar.h
index 42879d2ef..1e1825351 100644
--- a/users/spacebarracecar/spacebarracecar.h
+++ b/users/spacebarracecar/spacebarracecar.h
@@ -4,13 +4,14 @@
#include "keymap_german.h"
enum userspace_layers {
- _DEADKEY = 14, //change if more than 16 layers are required
+ _DEADKEY = 14, // Change if more than 16 layers are required
_NAV
};
enum userspace_custom_keycodes {
CU_GAME = SAFE_RANGE, // Toggle game mode on/off
CU_NAV, // NAV | ESC
+ KC_P00, // Numpad double zero
#ifdef GERMAN_ENABLE
CU_LSFT, // LSFT | (
@@ -52,10 +53,8 @@ enum userspace_custom_keycodes {
};
#ifdef GERMAN_ENABLE
-// these save the current shift status
extern bool lshift;
extern bool rshift;
-// stuff for custom space cadet shift
extern bool lshiftp;
extern bool rshiftp;
extern uint16_t lshift_timer;
@@ -63,14 +62,12 @@ extern uint16_t rshift_timer;
extern uint8_t prev_indx;
extern uint16_t prev_kcs[6];
-
void add_to_prev(uint16_t kc);
void unreg_prev(void);
extern bool esct;
#endif
-// stuff for nav esc
extern bool navesc;
extern uint16_t navesc_timer;
@@ -78,7 +75,7 @@ extern bool game;
void timer_timeout(void);
-bool process_record_userspace(uint16_t keycode, keyrecord_t *record);
+bool process_record_keymap(uint16_t keycode, keyrecord_t *record);
#define CTRLX LCTL(KC_X)
#define CTRLC LCTL(KC_C)
@@ -89,9 +86,9 @@ bool process_record_userspace(uint16_t keycode, keyrecord_t *record);
#define GUIL LGUI(KC_LEFT)
#define GUIR RGUI(KC_RIGHT)
-//
-// Templates for Keys, with custom shifted and non shifted Characters
-//
+/*
+Templates for Keys, with custom shifted and non shifted Characters
+*/
// Normal shift status
#define SHIFT_NORM(kc1, kc2) \
@@ -139,7 +136,7 @@ if (record->event.pressed) { \
} \
return false;
-// All shift
+// Always shifted
#define SHIFT_ALL(kc1, kc2) \
if (record->event.pressed) { \
timer_timeout(); \
@@ -164,7 +161,7 @@ if (record->event.pressed) { \
} \
return false;
-// All no shift
+// Never shifted
#define SHIFT_NO(kc1, kc2) \
if (record->event.pressed) { \
timer_timeout(); \
@@ -188,7 +185,7 @@ if (record->event.pressed) { \
} \
return false;
-// All algr
+// Always AltGr
#define SHIFT_ALGR(kc1, kc2) \
if (record->event.pressed) { \
timer_timeout(); \
@@ -208,7 +205,7 @@ if (record->event.pressed) { \
} \
return false;
-// Different keycode for ctrl
+// Different keycode when Ctrl is pressed
#define CTRL(kc1, kc2) \
if(record->event.pressed) { \
timer_timeout(); \
@@ -227,7 +224,7 @@ if(record->event.pressed) { \
} \
return false;
// Umlaute for deadkey layer
#define UML(kc) \
if(record->event.pressed) { \
timer_timeout(); \
@@ -227,7 +224,7 @@ if(record->event.pressed) { \
} \
return false;
-// Umlaute for deadkey layer
+// Template for keys on deadkey layer (mostly Umlaute)
#define UML(kc) \
if(record->event.pressed) { \